@@ -14,7 +14,7 @@ class Bowtie2(Tool):
     The bowtie2 implementation of the Tool class.
     """
     def __init__(self, tool_args, output_name, inputs, output_path,
-                 database_name, database_version):
+                 database_name, database_version, **kwargs):
         super().__init__(
             tool_name="bowtie2",
             tool_version="2.4.4",  # todo: allow bowtie2 version to be set by the user
@@ -30,4 +30,5 @@ class Bowtie2(Tool):
             output_type=OutputType.GZ_TAR,
             output_is_directory=True,
             output_names=["bowtie2.log", "bowtie2_output.sam"],
+            **kwargs,
         )
