@@ -37,7 +37,7 @@ class Tool:
                  max_input_bytes_per_file_parallel=FOUR_POINT_FIVE_GIGABYTES,
                  group_paired_ends=False, compress_inputs=False,
                  output_type=OutputType.FLAT_TEXT, output_is_directory=True,
-                 output_names=None, is_async=False):
+                 output_names=None, is_async=False, skip_decompression=False):
         self.tool_name = tool_name
         self.tool_version = tool_version
         self.tool_args = tool_args
@@ -76,6 +76,7 @@ class Tool:
         self.thread_outputs = {}
         self.output_names = output_names or []
         self.is_async = is_async
+        self.skip_decompression = skip_decompression
         signal.signal(signal.SIGTERM, self._handle_termination)
         signal.signal(signal.SIGINT, self._handle_termination)
 
@@ -209,8 +210,9 @@ class Tool:
 
     def _warn_if_outputs_exist(self):
         """Warns if default output files already exist in the output directory"""
+        output_dir = self.output_path if self.output_is_directory else os.path.dirname(self.output_path)
         for file_path in self.output_names + ["output", "output.tar.gz"]:
-            joined_file_path = os.path.join(self.output_path, file_path)
+            joined_file_path = os.path.join(output_dir, file_path)
             if os.path.exists(joined_file_path):
                 print(f"WARNING: {joined_file_path} already exists and will be overwritten")
 
@@ -246,7 +248,10 @@ class Tool:
                         output_file_path = f"{self.output_path}/{output_name}"
                         sanity_check(output_file_path)
                 else:
-                    sanity_check(self.output_path)
+                    # TODO: verify that this works with absolute pathing
+                    for output_name in self.output_names:
+                        output_file_path = f"{os.path.dirname(self.output_path)}/{output_name}"
+                        sanity_check(output_file_path)
 
     def _system_supports_parallel_execution(self):
         """Checks if parallel execution is supported on the platform.
@@ -435,6 +440,7 @@ class Tool:
                 "input_prefix_mapping": self.input_prefix_mapping,
                 "output_path": temp_parallel_output_file_path if should_run_in_parallel else non_parallel_output_path,
                 "output_type": self.output_type,
+                "skip_decompression": self.skip_decompression,
             })
 
             # Add non-distinct dictionary for status updates
